# reach_five_identity_repo (EXPERIMENTAL)
# Introduction
Welcome to the documentation reference for the ReachFive REST Identity API!

This API is documented in **OpenAPI standard**, and rendered using [ReDoc](https://github.com/Redocly/redoc).

If something is missing, incorrect, or unclear, reach us at <documentation@reach5.co>.


# Environment
Endpoints are available at `https://{YOUR_DOMAIN}{ENDPOINT}`.

Find how to obtain your ReachFive domain [here](https://developer.reachfive.com/docs/console.html#access-your-reachfive-console).

# First and third-party clients

Except if you want to implement OpenID as a Service (OaaS), **always** use first-party clients.

In the context of OaaS, third-party clients are used to make calls to:

- [/oauth/authorize](#operation/authorizeUser)
- [/oauth/token](#operation/retrieveAccessToken)

They **cannot** be used with other endpoints.

If you to call any other endpoint with a third-party client, you will get this error:

```
{
  \"error_id\": \"9z8h7JmIHU\",
  \"error_description\": \"Not a first party identity client\",
  \"error_message_key\": \"error.client.notFirstParty\",
  \"error\": \"unauthorized_client\",
  \"error_user_msg\": \"Not a first party identity client\"
}
```

# Errors

The API uses standard HTTP status codes to indicate the success or failure of the API call.

|Code   |Notes                                                                                           |
|-------|------------------------------------------------------------------------------------------------|
|`2xx`  | Success codes; indicates the request worked as expected.                                  |
|`4xx`  | Error codes; indicates a client (user) error and more information is provided. See the example below.       |
|`5xx`  | Server error codes; indicates an error with one of ReachFive's servers.                        |

The error body is JSON and contains the following fields:

```
{
    \"error_id\": \"2hNBbvYecw\",
    \"error_description\": \"Invalid email or password\",
    \"error_message_key\": \"error.invalidEmailOrPassword\",
    \"error\": \"invalid_grant\",
    \"error_user_msg\": \"Invalid email or password\"
}
```

- `error_id` is the auto-generated ID of the error.
- `error_description` is the default error description.
- `error_message_key` is the unique key that can be used to bind specific behaviors on other services. This also acts as the `i18n` translation key.
- `error` is the error type. See the Error Types table below for more details.
- `error_user_msg` is a user-friendly error message that should be used in the UI. This can be overriden in certain configurations.

|Error Type|
|----------|
|`server_error`|
|`invalid_request`|
|`invalid_state`|
|`invalid_grant`|
|`invalid_scope`|
|`insufficient_scope`|
|`access_denied`|
|`origin_not_allowed`|
|`ip_address_not_allowed`|
|`missing_config`|
|`invalid_config`|
|`resource_not_found`|
|`temporarily_unavailable`|
|`unsupported_grant_type`|
|`unsupported_algorithm`|
|`invalid_client`|
|`unauthorized_client`|
|`login_required`|
|`email_already_exists`|
|`external_id_already_exists`|
|`phone_number_already_exists`|
|`lite_profile_invalid_identifiers`|
|`lite_profile_missing_profile`|
|`password_too_weak`|
|`rate_limit_reached`|
|`webhook_host_unreachable`|
|`webhook_invalid_response`|

**Tip**: For more information, see the individual endpoints.

# Security Schemes
<SecurityDefinitions />


This Dart package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: latest
- Build package: org.openapitools.codegen.languages.DartDioClientCodegen

## Requirements

* Dart 2.12.0 or later OR Flutter 1.26.0 or later
* Dio 4.0.0+

## Installation & Usage

### pub.dev
To use the package from [pub.dev](https://pub.dev), please include the following in pubspec.yaml
```yaml
dependencies:
  reach_five_identity_repo: 0.1.7
```

### Github
If this Dart package is published to Github, please include the following in pubspec.yaml
```yaml
dependencies:
  reach_five_identity_repo:
    git:
      url: https://github.com/GIT_USER_ID/GIT_REPO_ID.git
      #ref: main
```

### Local development
To use the package from your local drive, please include the following in pubspec.yaml
```yaml
dependencies:
  reach_five_identity_repo:
    path: /path/to/reach_five_identity_repo
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```dart
import 'package:reach_five_identity_repo/reach_five_identity_repo.dart';


final api = ReachFiveIdentityRepo().getOAuthApi();
final RevokeTokenRequest revokeTokenRequest = ; // RevokeTokenRequest | 

try {
    api.revokeToken(revokeTokenRequest);
} catch on DioError (e) {
    print("Exception when calling OAuthApi->revokeToken: $e\n");
}

```

## Documentation for API Endpoints

All URIs are relative to *https://YOUR_DOMAIN*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
[*OAuthApi*](doc/OAuthApi.md) | [**revokeToken**](doc/OAuthApi.md#revoketoken) | **POST** /oauth/revoke | Revoke a token


## Documentation For Models

 - [RevokeTokenRequest](doc/RevokeTokenRequest.md)


## Documentation For Authorization

 All endpoints do not require authorization.


## Author

documentation@reach5.co

